import subprocess as sub
import mash
import mash.config
import StringIO
from ConfigParser import RawConfigParser

from libtaskotron.directives import BaseDirective
from libtaskotron.logger import log
from libtaskotron.exceptions import TaskotronDirectiveError

directive_class = 'MashDirective'

class MashDirective(BaseDirective):
    def do_mash(self, rpmdir, dodelta, arch):
        # copied over from the old depcheck
        distname = 'depcheck'

        mash_conf_items = ["[%s]" % distname,
                           #"output_subdir = %s" % distname,
                           "rpm_path = %s" % rpmdir,
                           "strict_keys = False",
                           "multilib = True",
                           "multilib_method = devel",
                           "tag = this-is-a-dummy-tag",
                           "inherit = False",
                           "debuginfo = False",
                           "delta = %s" % dodelta,
                           "source = False",
                           "arches = %s" % arch,
                           "keys = ",]
        mash_conf = '\n'.join(mash_conf_items)

        conf = mash.config.readMainConfig('/etc/mash/mash.conf')
        dist = mash.config.MashDistroConfig()
        parser = RawConfigParser()

        parser.readfp(StringIO.StringIO(mash_conf))
        dist.populate(parser, distname, conf)
        conf.distros.append(dist)
        dist.repodata_path = dist.rpm_path
        dist.name = distname

        themash = mash.Mash(dist)
        themash.logger.handlers = [themash.logger.handlers[-1]]

        log.info('running createrepo on %s', rpmdir)
        p = sub.Popen(['createrepo', rpmdir], stdout=sub.PIPE, stderr=sub.PIPE)

        output, errors = p.communicate()

        if p.returncode:
            raise TaskotronDirectiveError(errors)

        log.info('running mash multilib on %s', rpmdir)
        rc = themash.doMultilib()
        conf.distros.pop()

        return rc

    def process(self, input_data, env_data):
        """For the mash directive, we're expecting a yaml declaration of
        the form:

        mash:
          rpmdir=/path/to/some/dir
          dodelta=[True, False]
          arch=["i386", "x86_64", "armhfp", "noarch"]
        """

        if 'rpmdir' not in input_data or 'arch' not in input_data:
            detected_args = ', '.join(input_data.keys())
            raise TaskotronDirectiveError(
                "The mash directive requires 'rpmdir' and 'arch' "
                "arguments. Detected arguments: %s" % detected_args)

        if 'dodelta' not in input_data:
            dodelta = False
        else:
            dodelta = input_data['dodelta']

        rpmdir = input_data['rpmdir']
        arch = input_data['arch']

        self.do_mash(rpmdir, dodelta, arch)
